filter_unsp<-function(h,...){
	f<-function(h,...){
			x<<-svalue(h$obj)
		}
	try(({
		dat2Affy.m<-dat2Affy.m;datAgOne2.m<-datAgOne2.m;datAgTwo2.m<-datAgTwo2.m;datIllBA2.m2<-datIllBA2.m2;
		lumi_NQ.m<-lumi_NQ.m;data.matrix_Nimblegen2.m<-data.matrix_Nimblegen2.m;
		data.matrixNorm.m<-data.matrixNorm.m;data.matrix_onlineNorm.m<-data.matrix_onlineNorm.m;
		groups_Affy<-groups_Affy;groups_Ag1<-groups_Ag1;groups_Ag2<-groups_Ag2;groups_Il_B<-groups_Il_B;groups_Il_L<-groups_Il_L;
		groups_N<-groups_N;groups_S<-groups_S;groups_O<-groups_O;types<-types;
		l<-l;tree<-tree;
	}),silent=TRUE)
	platforms=NULL;
	aa=0;bb=0;cc=0;dd=0;ee=0;ff=0;gg=0;hh=0;
	try(({
		if(exists("dat2Affy.m"))aa=length(dat2Affy.m)
		if(exists("datAgOne2.m"))bb=length(datAgOne2.m)
		if(exists("datAgTwo2.m"))cc=length(datAgTwo2.m)
		if(exists("datIllBA2.m2"))dd=length(datIllBA2.m2)
		if(exists("lumi_NQ.m"))ee=length(lumi_NQ.m)
		if(exists("data.matrix_Nimblegen2.m"))ff=length(data.matrix_Nimblegen2.m)
		if(exists("data.matrixNorm.m"))gg=length(data.matrixNorm.m)
		if(exists("data.matrix_onlineNorm.m"))hh=length(data.matrix_onlineNorm.m)
		}),silent=TRUE)
	if(aa!=0)platforms=c(platforms,"Affymetrix")
	if(bb!=0)platforms=c(platforms,"Agilent_OneColor")
	if(cc!=0)platforms=c(platforms,"Agilent_TwoColor")
	if(dd!=0)platforms=c(platforms,"Illumina_Beadarray")
	if(ee!=0)platforms=c(platforms,"Illumina_Lumi")
	if(ff!=0)platforms=c(platforms,"Nimblegen")
	if(gg!=0)platforms=c(platforms,"Series_Matrix")
	if(hh!=0)platforms=c(platforms,"Online_Data")

	dat2Affy.f=NULL;datAgOne2.f=NULL;datAgTwo2.f=NULL;datIllBA2.f=NULL;lumi_NQ.f=NULL;
	data.matrix_Nimblegen2.f=NULL;data.matrixNorm.f=NULL;data.matrix_onlineNorm.f=NULL;
	use.dat2Affy.m=NULL;use.datAgOne2.m=NULL;use.datAgTwo2.m=NULL;use.datIllBA2.m2=NULL;use.lumi_NQ.m=NULL;
	use.data.matrix_Nimblegen2.m=NULL;use.data.matrixNorm.m=NULL;use.data.matrix_onlineNorm.m=NULL;

	rm(dat2Affy.f,datAgOne2.f,datAgTwo2.f,datIllBA2.f,lumi_NQ.f,data.matrix_Nimblegen2.f,data.matrixNorm.f,data.matrix_onlineNorm.f,
	use.dat2Affy.m,use.datAgOne2.m,use.datAgTwo2.m,use.datIllBA2.m2,use.lumi_NQ.m,
	use.data.matrix_Nimblegen2.m,use.data.matrixNorm.m,use.data.matrix_onlineNorm.m)

	x=NULL
	z=NULL
	unsf_xx=NULL
	unsf_methods=c("Standard_Deviation_Filter","Expression_Filter")
	unsf_w<-gwindow("Select a Filter",width=300,height=150)
	unsf_gp<-ggroup(container=unsf_w,fill="y")
	unsf_x<-gtable(unsf_methods,chosencol=1,container=unsf_gp)
	size(unsf_x)=c(200,100)
	unsf_gp2<-ggroup(container=unsf_gp,width=30,height=15,fill="x")
	addHandlerClicked(unsf_x,handler=function(h,...){
		unsf_x2<-svalue(h$obj)
		unsf_xx<<-unsf_x2
		}
	)
	addSpring(unsf_gp2)
	unsf_y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(unsf_w)
		},container=unsf_gp2,anchor=c(1,-1)
	)
	unsf_y2<-gbutton("OK",border=TRUE,handler=function(h,...){
		dispose(unsf_w)
		svalue(sb)<-"Working... Plz wait..."
		Sys.sleep(1)
		if(unsf_xx=="Standard_Deviation_Filter")
		{
			w_f<-gwindow("Select your data",width=260,height=280,visible=FALSE)
			gp_f<-ggroup(container=w_f,fill="y")
			size(gp_f)=c(220,180)
			cbg<-gcheckboxgroup(platforms,container=gp_f,handler=f)
			svalue(cbg,index=FALSE)<-1:8
			gp2_f<-ggroup(container=gp_f,width=30,height=15,fill="x")
			addSpring(gp2_f)
			y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
				dispose(w_f)
				},container=gp2_f,anchor=c(1,-1))
			y2<-gbutton("OK",border=TRUE,handler=function(h,...){
				if(length(x)!=0){
					dispose(w_f)
					svalue(sb)<-"				Please wait while Filtering.."
					if(length(which(x=="Affymetrix"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.dat2Affy.m<<-dat2Affy.m
							if(exists("groups_Affy"))rm(groups_Affy,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.dat2Affy.m)
							i<-rsd>=std
							dat.f<-use.dat2Affy.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							dat2Affy.f<<-fit2
							if(length(dat2Affy.f)!=0){
								visible(g1_1)<-FALSE
								l$Affymetrix$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(dat2Affy.f)							
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Agilent_OneColor"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.datAgOne2.m<<-datAgOne2.m
							if(exists("groups_Ag1"))rm(groups_Ag1,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.datAgOne2.m)
							i<-rsd>=std
							dat.f<-use.datAgOne2.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							datAgOne2.f<<-fit2
							if(length(datAgOne2.f)!=0){
								visible(g1_1)<-FALSE
								l$Agilent_OneColor$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(datAgOne2.f)				
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Agilent_TwoColor"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.datAgTwo2.m<<-datAgTwo2.m
							if(exists("groups_Ag2"))rm(groups_Ag2,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.datAgTwo2.m)
							i<-rsd>=std
							dat.f<-use.datAgTwo2.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							datAgTwo2.f<<-fit2
							if(length(datAgTwo2.f)!=0){
								visible(g1_1)<-FALSE
								l$Agilent_TwoColor$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(datAgTwo2.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Illumina_Beadarray"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.datIllBA2.m2<<-datIllBA2.m2
							if(exists("groups_Il_B"))rm(groups_Il_B,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.datIllBA2.m2)
							i<-rsd>=std
							dat.f<-use.datIllBA2.m2[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							datIllBA2.f<<-fit2
							if(length(datIllBA2.f)!=0){
								visible(g1_1)<-FALSE
								l$Illumina_Beadarray$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(datIllBA2.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Illumina_Lumi"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.lumi_NQ.m<<-lumi_NQ.m
							if(exists("groups_Il_L"))rm(groups_Il_L,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.lumi_NQ.m)
							i<-rsd>=std
							dat.f<-use.lumi_NQ.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							lumi_NQ.f<<-fit2
							if(length(lumi_NQ.f)!=0){
								visible(g1_1)<-FALSE
								l$Illumina_Lumi$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(lumi_NQ.f)							
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Nimblegen"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.data.matrix_Nimblegen2.m<<-data.matrix_Nimblegen2.m
							if(exists("groups_N"))rm(groups_N,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.data.matrix_Nimblegen2.m)
							i<-rsd>=std
							dat.f<-use.data.matrix_Nimblegen2.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							data.matrix_Nimblegen2.f<<-fit2
							if(length(data.matrix_Nimblegen2.f)!=0){
								visible(g1_1)<-FALSE
								l$Nimblegen$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(data.matrix_Nimblegen2.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Series_Matrix"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.data.matrixNorm.m<<-data.matrixNorm.m
							if(exists("groups_S"))rm(groups_S,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.data.matrixNorm.m)
							i<-rsd>=std
							dat.f<-use.data.matrixNorm.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							data.matrixNorm.f<<-fit2
							if(length(data.matrixNorm.f)!=0){
								visible(g1_1)<-FALSE
								l$Series_Matrix$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(data.matrixNorm.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Online_Data"))!=0){
						w_ef<-gwindow("Standard_Deviation_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Standard Deviation Value ",container=gp1)
						std_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							std<-as.numeric(svalue(std_box))
							dispose(w_ef)
							use.data.matrix_onlineNorm.m<<-data.matrix_onlineNorm.m
							if(exists("groups_O"))rm(groups_O,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							rsd<-rowSds(use.data.matrix_onlineNorm.m)
							i<-rsd>=std
							dat.f<-use.data.matrix_onlineNorm.m[i,]
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							data.matrix_onlineNorm.f<<-fit2
							if(length(data.matrix_onlineNorm.f)!=0){
								visible(g1_1)<-FALSE
								l$Online_Data$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(data.matrix_onlineNorm.f)
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					svalue(sb)<-"Done"
					dispose(w_f)
					}else{
					gmessage("Plz select the data for filtering","Select Data")
					}
				},container=gp2_f,anchor=c(1,-1))
			visible(w_f)<-TRUE
			}
		else if(unsf_xx=="Expression_Filter")
		{
			w_f<-gwindow("Select your data",width=260,height=280,visible=FALSE)
			gp_f<-ggroup(container=w_f,fill="y")
			size(gp_f)=c(220,180)
			cbg<-gcheckboxgroup(platforms,container=gp_f,handler=f)
			svalue(cbg,index=FALSE)<-1:8
			gp2_f<-ggroup(container=gp_f,width=30,height=15,fill="x")
			addSpring(gp2_f)
			y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
				dispose(w_f)
				},container=gp2_f,anchor=c(1,-1))
			y2<-gbutton("OK",border=TRUE,handler=function(h,...){
				if(length(x)!=0){
					dispose(w_f)
					svalue(sb)<-"				Please wait while Filtering.."
					if(length(which(x=="Affymetrix"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.dat2Affy.m<<-dat2Affy.m
							if(exists("groups_Affy"))rm(groups_Affy,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.dat2Affy.m,ff)
							dat.fo<-use.dat2Affy.m[i,]
							i<-genefilter(-use.dat2Affy.m,ff)
							dat.fu<-use.dat2Affy.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							dat2Affy.f<<-fit2
							if(length(dat2Affy.f)!=0){
								visible(g1_1)<-FALSE
								l$Affymetrix$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
							stat_sign(dat2Affy.f)
							}							
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Agilent_OneColor"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.datAgOne2.m<<-datAgOne2.m
							if(exists("groups_Ag1"))rm(groups_Ag1,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.datAgOne2.m,ff)
							dat.fo<-use.datAgOne2.m[i,]
							i<-genefilter(-use.datAgOne2.m,ff)
							dat.fu<-use.datAgOne2.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							datAgOne2.f<<-fit2
							if(length(datAgOne2.f)!=0){
								visible(g1_1)<-FALSE
								l$Agilent_OneColor$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(datAgOne2.f)									
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Agilent_TwoColor"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.datAgTwo2.m<<-datAgTwo2.m
							if(exists("groups_Ag2"))rm(groups_Ag2,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.datAgTwo2.m,ff)
							dat.fo<-use.datAgTwo2.m[i,]
							i<-genefilter(-use.datAgTwo2.m,ff)
							dat.fu<-use.datAgTwo2.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							datAgTwo2.f<<-fit2
							if(length(datAgTwo2.f)!=0){
								visible(g1_1)<-FALSE
								l$Agilent_TwoColor$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(datAgTwo2.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Illumina_Beadarray"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.datIllBA2.m2<<-datIllBA2.m2
							if(exists("groups_Il_B"))rm(groups_Il_B,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.datIllBA2.m2,ff)
							dat.fo<-use.datIllBA2.m2[i,]
							i<-genefilter(-use.datIllBA2.m2,ff)
							dat.fu<-use.datIllBA2.m2[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							datIllBA2.f<<-fit2
							if(length(datIllBA2.f)!=0){
								visible(g1_1)<-FALSE
								l$Illumina_Beadarray$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(datIllBA2.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Illumina_Lumi"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.lumi_NQ.m<<-lumi_NQ.m
							if(exists("groups_Il_L"))rm(groups_Il_L,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.lumi_NQ.m,ff)
							dat.fo<-use.lumi_NQ.m[i,]
							i<-genefilter(-use.lumi_NQ.m,ff)
							dat.fu<-use.lumi_NQ.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							lumi_NQ.f<<-fit2
							if(length(lumi_NQ.f)!=0){
								visible(g1_1)<-FALSE
								l$Illumina_Lumi$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(lumi_NQ.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Nimblegen"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.data.matrix_Nimblegen2.m<<-data.matrix_Nimblegen2.m
							if(exists("groups_N"))rm(groups_N,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.data.matrix_Nimblegen2.m,ff)
							dat.fo<-use.data.matrix_Nimblegen2.m[i,]
							i<-genefilter(-use.data.matrix_Nimblegen2.m,ff)
							dat.fu<-use.data.matrix_Nimblegen2.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							data.matrix_Nimblegen2.f<<-fit2
							if(length(data.matrix_Nimblegen2.f)!=0){
								visible(g1_1)<-FALSE
								l$Nimblegen$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(data.matrix_Nimblegen2.f)
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Series_Matrix"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.data.matrixNorm.m<<-data.matrixNorm.m
							if(exists("groups_S"))rm(groups_S,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.data.matrixNorm.m,ff)
							dat.fo<-use.data.matrixNorm.m[i,]
							i<-genefilter(-use.data.matrixNorm.m,ff)
							dat.fu<-use.data.matrixNorm.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							data.matrixNorm.f<<-fit2
							if(length(data.matrixNorm.f)!=0){
								visible(g1_1)<-FALSE
								l$Series_Matrix$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(data.matrixNorm.f)								
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					if(length(which(x=="Online_Data"))!=0){
						w_ef<-gwindow("Expression_Filter",fill="y",height=100,width=100)
						gpc<-ggroup(container=w_ef,fill="y")
						gp1<-ggroup(container=gpc,fill="x")
						glabel("Over Expression Value ",container=gp1)
						ove_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp1,anchor=c(-1,1))
						gp2<-ggroup(container=gpc,fill="x")
						glabel("Percentage of Samples",container=gp2)
						posp_box<-gedit("",initial.msg="gene names",width=12,height=20,container=gp2,anchor=c(-1,1))
						gp3<-ggroup(container=gpc,width=30,height=15,fill="x")
						addSpring(gp3)
						y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
							dispose(w_ef)
						},container=gp3,anchor=c(1,-1))
						y2<-gbutton("OK",border=TRUE,handler=function(h,...){
							ove<-as.numeric(svalue(ove_box))
							posp<-as.numeric(svalue(posp_box))
							dispose(w_ef)
							use.data.matrix_onlineNorm.m<<-data.matrix_onlineNorm.m
							if(exists("groups_O"))rm(groups_O,envir=globalenv())
							if(exists("types"))rm(types,envir=globalenv())
							ff<-pOverA(A=ove,p=posp)
							i<-genefilter(use.data.matrix_onlineNorm.m,ff)
							dat.fo<-use.data.matrix_onlineNorm.m[i,]
							i<-genefilter(-use.data.matrix_onlineNorm.m,ff)
							dat.fu<-use.data.matrix_onlineNorm.m[i,]
							dat.f<-rbind(dat.fo,dat.fu)
							fit<-lmFit(dat.f)
							yy<-try(fit2<-eBayes(fit),silent=TRUE)
							if(length(grep("Error",yy))!=0)
							{
								fit2<-fit
							}
							data.matrix_onlineNorm.f<<-fit2
							if(length(data.matrix_onlineNorm.f)!=0){
								visible(g1_1)<-FALSE
								l$Online_Data$Filtered<<-list()
								tr<<-gtree(offspring=tree,container=g1_1)
								size(tr)<-c(300,400)
								visible(g1_1)<-TRUE
								stat_sign(data.matrix_onlineNorm.f)
								}
							display()
						},container=gp3,anchor=c(1,-1))
					}
					svalue(sb)<-"Done"
					dispose(w_f)
					}else{
					gmessage("Plz select the data for filtering","Select Data")
					}
				},container=gp2_f,anchor=c(1,-1))
			visible(w_f)<-TRUE
			}
		svalue(sb)<-"Done"
		},container=unsf_gp2,anchor=c(1,-1)
	)
}	

